//do-file for "Regression diagnostics"
//use ESS5GBdiagnostics.dta


// Model assumptions
quietly regress trstlgl age woman political_interest religious
linktest															// linktest for specification error

quietly regress trstlgl age woman political_interest religious
ovtest																// ovtest for omitted variables

// Curvilinearity
lowess trstlgl age, nograph gen(yhatlowess)							// predicts value of regression
line yhatlowess age, sort											// graph bivariate relationship

regress trstlgl c.age##c.age woman political_interest religious		// regression including squared term

margins, at(age=(15(1)98))
marginsplot, noci													// marginsplot

regress trstlgl c.age##c.age##i.woman political_interest religious		// regression including squared term and interaction effect

margins, at (age=(15(1)98) woman=(0 1))
marginsplot, noci													// marginsplot


lowess happy age, nograph gen(yhatlowess2)							// predicts value of regression
line yhatlowess2 age, sort 											// graph bivariate relationship

regress happy c.age##c.age##c.age woman political_interest religious leftright

margins, at(age=(15(1)98))
marginsplot, noci													// marginsplot

regress edagegb woman religious leftright

regress edagegb woman religious c.lrscale##c.lrscale
margins, at(lrscale=(0(1)10))
marginsplot, noci

// Curvilinearity and dummy variables

generate Dleft = (lrscale < 3) if !missing(lrscale)
generate Dcentre = (lrscale > 2 & lrscale < 8) if !missing(lrscale)
generate Dright = (lrscale > 7) if !missing(lrscale)

regress edagegb woman religious Dleft Dright 


//Multicollienarity
quietly regress trstlgl age woman political_interest religious
vif																	// variance inflation factor and tolerance

//Regcheck
ssc install regcheck												// installs the regcheck programme
quietly regress trstlgl age woman political_interest religious
regcheck															// runs regcheck


//Homoskedasticity

quietly regress trstlgl age woman political_interest religious
rvfplot																// produces plot of teh predicted values versus the residuals
hettest																// Breusch-Pagan / Cook-Weisberg test for heteroskedasticity


//Uncorrelated errors
//use Durbin_Watson.dta

tsset year															// time-sets the data	
regress FDI GDPperCapita GDGrowth incidence
estat dwatson														// produces Durbin-Watson statistic


//Normally distributed errors
//use ESS5GBdiagnostics.dta

quietly regress trstlgl age woman political_interest religious
predict res, residual												// saves residuals as a variable

hist res, normal													// histogram of residuals, displaying normal curve
summarize res, detail
sktest res															// skewness/kurtosis test for normality


//Influential observations
//use Influential_units.dta

quietly regress lnFDI GDPperCapita GDPGrowth incidence ethfrac
predict h if e(sample), hat											// saves hat statistic as a variable
graph box h, mark (1, mlab(ccode))									// produces box plot of hat statistic, labeling cases


regress lnFDI GDPperCapita GDPGrowth incidence ethfrac
regress lnFDI GDPperCapita GDPGrowth incidence ethfrac if ccode!=NOR	// regression excluding potentially influential observation


quietly regress lnFDI GDPperCapita GDPGrowth incidence ethfrac
dfbeta GDPperCapita GDPGrowth incidence ethfrac						// saves DFBETA values as variables
graph box _dfbeta_1 _dfbeta_2 _dfbeta_3 _dfbeta_4, marker(1, mlab(ccode)) marker(2, mlab(ccode)) marker(3, mlab(ccode)) marker(4, mlab(ccode))  // produces box plot of DFBETA statistic, labeling cases

quietly regress lnFDI GDPperCapita GDPGrowth incidence ethfrac
predict cooksd if e(sample), cooksd									// saves Cook's distance as a variable
graph box cooksd, mark(1, mlab(ccode))								// produces box plot of Cook's D, labeling cases
browse ccode cooksd if cooksd > 0.029 & e(sample)					// lets you inspect influential cases







